@@ -39,11 +39,12 @@ public:
     KimpanelInputPanel(QWidget* parent = 0);
     virtual ~KimpanelInputPanel();
 
-    void setSpotLocation(int x, int y);
-    void setSpotLocation(const QPoint& point);
+    void setSpotLocation(const QRect& rect);
+    void updateLocation();
     void setShowPreedit(bool show);
     void setShowAux(bool show);
     void setShowLookupTable(bool show);
+    void setLookupTableCursor(int cursor);
     void setPreeditCaret(int pos);
     void setPreeditText(const QString& text,
                         const QString& attrs = QString());
@@ -77,6 +78,7 @@ private:
     Plasma::FrameSvg* m_backgroundSvg;
     QPoint m_pointPos;
     bool m_moving;
+    QRect m_spotRect;
 };
 
 #endif // KIMPANEL_INPUTPANEL_H
